#!/bin/sh
# Asset server install script v. 1.0.0
# Run this script as root to install the service

prefix=/opt/unity_asset_server
owner=unitysrv
group=unitysrv
port=10733

postgres_src=postgresql-8.2.5

croak() {
	echo $1
	exit 1
}


# Add unitysrv user account
if /usr/sbin/useradd -h 2>&1 | grep -- -r > /dev/null; then
	/usr/sbin/useradd -r -d $prefix $owner 2> /dev/null || :
else
	/usr/sbin/useradd -d $prefix $owner 2> /dev/null || :
fi	
# Add unitysrv group
/usr/sbin/groupadd $group 2> /dev/null || :

id $owner > /dev/null 2>&1 || croak "Could not create $owner user. Please create a user account called $owner and rerun this script"

if [ -f /etc/init.d/unity_asset_server ] ; then	
	if [ -x /sbin/service ] ; then # Redhat/Fedora/CentOS
		/sbin/service unity_asset_server stop > /dev/null 2>&1 || :
	else # Generic SysV Init
		/etc/init.d/unity_asset_server stop > /dev/null 2>&1 || :
	fi
fi

mkdir -p $prefix/log
chown $owner.$group $prefix/log
touch $prefix/log/build.log

(cd $postgres_src; ./configure CFLAGS="-Os" --prefix=$prefix --without-docdir --with-pgport=$port  --without-readline) | tee -a $prefix/log/build.log
(make -C $postgres_src && make -C $postgres_src install) | tee -a $prefix/log/build.log || croak "Failed building Unity Asset Server."

(PATH=$prefix/bin:$PATH make -C UnityExtensions ) | tee -a $prefix/log/build.log || croak "Failed building Unity Asset Server."
(PATH=$prefix/bin:$PATH make -C UnityExtensions install ) | tee -a $prefix/log/build.log || croak "Failed building Unity Asset Server."


cp unity_build/postgresql.conf.default $prefix/share/postgresql.conf.default
cp unity_build/postgresql.conf.init $prefix/share/postgresql.conf.init
cp unity_build/pg_hba.conf.default $prefix/share/pg_hba.conf.default
cp unity_build/pg_hba.conf.init $prefix/share/pg_hba.conf.init
cp unity_build/db_source.sql.bz2 $prefix/share/db_source.sql.bz2
cp unity_build/reset_admin_password.sh $prefix/bin/reset_admin_password
chmod 755 $prefix/bin/reset_admin_password

if [ -x /sbin/runscript ] ; then # Gentoo Linux
	cp unity_build/unity_asset_server.runscript /etc/init.d/unity_asset_server
else
	cp unity_build/unity_asset_server.sysvinit /etc/init.d/unity_asset_server
fi
chmod 755 /etc/init.d/unity_asset_server


# open port 10733 to the world if apf is installed 
# The Liquid Web VPS hosting service uses apf for firewall configuration
if [ -x /usr/local/sbin/apf ] ; then
	/usr/local/sbin/apf -a tcp:in:d=$port:s=0.0.0.0/0 unity_asset_server >/dev/null || :
fi


if [ ! -d $prefix/data ]; then
	touch $prefix/log/install.log
	chown $owner.$group $prefix/log/*.log

	chown $owner $prefix
	su $owner -c "$prefix/bin/initdb -D $prefix/data >> $prefix/log/install.log 2>&1 " || croak "Could not initialize database directory"
	
	su $owner -c "cp $prefix/share/postgresql.conf.default $prefix/data/postgresql.conf"
	su $owner -c "cp $prefix/share/pg_hba.conf.default $prefix/data/pg_hba.conf"

	chown root $prefix
	
	if [ -x /sbin/service ] ; then
		/sbin/service unity_asset_server start
	else
		/etc/init.d/unity_asset_server start
	fi
	
	sleep 10 # wait for database to come up
	
	(bunzip2 -c < $prefix/share/db_source.sql.bz2 | $prefix/bin/psql -U $owner -p $port -d template1) >> $prefix/log/install.log 2>&1  || croak "Could not install Asset Server schema into database"
	$prefix/bin/vacuumdb  -U $owner -a -z >> $prefix/log/install.log 2>&1  || echo "Warning vacuuming failed."
else
	su $owner -c "cp $prefix/data/postgresql.conf $prefix/data/postgresql.conf~"
	su $owner -c "cp $prefix/data/pg_hba.conf $prefix/data/pg_hba.conf~"
	su $owner -c "cp $prefix/share/postgresql.conf.default $prefix/data/postgresql.conf"
	su $owner -c "cp $prefix/share/pg_hba.conf.default $prefix/data/pg_hba.conf"

	if [ -x /sbin/service ] ; then
		/sbin/service unity_asset_server start
	else
		/etc/init.d/unity_asset_server start
	fi
	sleep 10 # wait for database to come up
	
	# Recreate template1 from scratch:
	($prefix/bin/psql -U unitysrv -p 10733 -d template1 -c 'DROP SCHEMA public CASCADE;' ) >> $prefix/log/install.log 2>&1
	($prefix/bin/psql -U unitysrv -p 10733 -d template1 -c 'CREATE SCHEMA public;' ) >> $prefix/log/install.log 2>&1
	(bunzip2 -c < $prefix/share/db_source.sql.bz2 | $prefix/bin/psql -U unitysrv -p 10733 -d template1 ) >> $prefix/log/install.log 2>&1

	
	# Upgrade functions in databases
	for database in template1 `$prefix/bin/psql -U unitysrv -p 10733 -d postgres -c 'select databasename from all_databases__view' -A -t`
	do
		(bunzip2 -c < $prefix/share/db_upgrade_source.sql.bz2 | $prefix/bin/psql -U unitysrv -p 10733 -d $database) >> $prefix/log/install.log 2>&1  || croak "Could not update database $database."
	done
fi

if [ -x /sbin/rc-update ] ; then # Gentoo
	/sbin/rc-update add unity_asset_server default
elif [ -x /sbin/update-rc.d ] ; then # Debian?
	/usr/sbin/update-rc.d unity_asset_server defaults 80
else # Assume redhat-ish
	/sbin/chkconfig --add unity_asset_server
        /sbin/chkconfig unity_asset_server on
fi

$prefix/bin/reset_admin_password

